"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Case = require("case");
const chalk_1 = require("chalk");
const figlet = require("figlet");
const fs_1 = require("fs");
const handlebars_1 = require("handlebars");
const path_1 = require("path");
const process_1 = require("process");
class GenerateResolver extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(GenerateResolver);
        this.log(chalk_1.default.red(figlet.textSync('Ngen', { horizontalLayout: 'full' })));
        const __DIRNAME = __dirname;
        const CURR_DIR = process_1.cwd();
        this.log(chalk_1.default.blue('Resolver Generating...'));
        const source = fs_1.readFileSync(path_1.join(__DIRNAME, 'templates/resolver.hbs'), 'utf8').toString();
        const template = handlebars_1.compile(source);
        const content = template({
            name: args.name,
            camelName: Case.camel(args.name),
            pascalName: Case.pascal(args.name),
            kebabName: Case.kebab(args.name),
            all: flags.all
        });
        const writePath = `${CURR_DIR}/${Case.kebab(args.name)}.resolver.ts`;
        fs_1.writeFileSync(writePath, content, 'utf8');
        this.log(chalk_1.default.green('Resolver Generated!'));
        this.log(chalk_1.default.green('CREATE '), writePath);
    }
}
GenerateResolver.description = 'Generate Angular Resolver';
GenerateResolver.aliases = ['gr', 'g:r'];
GenerateResolver.flags = {
    help: command_1.flags.help({ char: 'h' }),
    all: command_1.flags.boolean({ char: 'a' })
};
GenerateResolver.args = [{ name: 'name' }];
exports.default = GenerateResolver;
