"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Case = require("case");
const chalk_1 = require("chalk");
const figlet = require("figlet");
const fs_1 = require("fs");
const handlebars_1 = require("handlebars");
const notifier = require("node-notifier");
const open = require("opn");
const path_1 = require("path");
const process_1 = require("process");
class MakeComponent extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(MakeComponent);
        this.log(chalk_1.default.red(figlet.textSync('Ngen', { horizontalLayout: 'full' })));
        const __DIRNAME = __dirname;
        const CURR_DIR = process_1.cwd();
        this.log(chalk_1.default.blue('Component Generating...'));
        const source = fs_1.readFileSync(path_1.join(__DIRNAME, 'templates/component.hbs'), 'utf8').toString();
        const template = handlebars_1.compile(source);
        const content = template({
            name: Case.camel(args.name),
            pascalName: Case.pascal(args.name),
            module: flags.module || 'module'
        });
        let writePath;
        // const name = flags.name || 'world'
        if (!flags.flat) {
            writePath = `${CURR_DIR}/${args.name}/${args.name}.component.js`;
            try {
                fs_1.mkdirSync(`${CURR_DIR}/${args.name}`);
            }
            catch (err) {
                if (err && err.code === 'EEXIST') {
                    this.warn('Directory exists');
                }
                // this.error(err, {code: '1', exit: 1})
            }
        }
        else {
            writePath = `${CURR_DIR}/${Case.snake(args.name)}.component.js`;
        }
        fs_1.writeFileSync(writePath, content, 'utf8');
        this.log(chalk_1.default.green('Component Generated!'));
        notifier.notify({
            title: 'Component Generated',
            message: 'CREATE: ' + writePath,
            icon: path_1.join(__DIRNAME, '../../img/cli.png')
        });
        if (flags.open) {
            open(writePath, { wait: false }).then(() => this.log('then')).catch(e => this.log('catch', e));
        }
    }
}
MakeComponent.description = 'Create an AngularJs Component';
MakeComponent.aliases = ['mc', 'm:c'];
MakeComponent.flags = {
    help: command_1.flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: command_1.flags.string({ char: 'n', description: 'name of the component' }),
    module: command_1.flags.string({ char: 'm', description: 'name of the module' }),
    // flag with no value (-f, --flat)
    flat: command_1.flags.boolean({ char: 'f', description: 'create component without subfolder' }),
    open: command_1.flags.boolean({ char: 'o', description: 'Open the generated file' })
};
MakeComponent.args = [
    { name: 'name' },
    { name: 'artifact' }
];
exports.default = MakeComponent;
